]> granicus.if.org Git - curl/commitdiff
If NTLM is requested, only re-use connections that have the exact same
authorDaniel Stenberg <daniel@haxx.se>
Sun, 20 Jul 2003 00:02:47 +0000 (00:02 +0000)
committerDaniel Stenberg <daniel@haxx.se>
Sun, 20 Jul 2003 00:02:47 +0000 (00:02 +0000)
credentials.

lib/url.c

index 5a91b8c0350476f44ca1a0e1a23b42a6c31794ba..b44f630c0ba88fd15ab29015261a773454c6fd02 100644 (file)
--- a/lib/url.c
+++ b/lib/url.c
@@ -1360,9 +1360,11 @@ ConnectionExists(struct SessionHandle *data,
             continue;
           }
         }
-        if(needle->protocol & PROT_FTP) {
-          /* This is FTP, verify that we're using the same name and
-             password as well */
+        if((needle->protocol & PROT_FTP) ||
+           ((needle->protocol & PROT_HTTP) &&
+            (needle->data->state.authwant==CURLAUTH_NTLM))) {
+          /* This is FTP or HTTP+NTLM, verify that we're using the same name
+             and password as well */
           if(!strequal(needle->user, check->user) ||
              !strequal(needle->passwd, check->passwd)) {
             /* one of them was different */